==> datapungi_fed-0.1.0.tar.gz: datapungi_fed-0.1.0/datapungi_fed/tests/test_driversCI.py <==
import datapungi_fed as dp
import time
import pandas as pd
import os


def executeCode(stringIn):
    '''
      auxiliary function for tests: get the requests code as a string and try to execute it.
    '''
    try:
        exec(stringIn+'\n')      #exec('print("hi")') #
        return(dict( codeRun = True, codeOutput = locals()['df_output']   ))   #try to output the dataframe called df_output
    except:
        try:
            exec(stringIn)  #if no dataframe called output, try to see it at least can exec the code
            return(dict(codeRun = True, codeOutput = pd.DataFrame([])))
        except:
            return(dict(codeRun = False, codeOutput = pd.DataFrame([])))

# content of test_sample.py
def test_startDriver(cmdopt):
    global data
    if not cmdopt == "":
        connectionParameters = {"key": cmdopt, "url": ""}
    else:
        connectionParameters = {}
    data = dp.data(connectionParameters)
    assert data
    return(data)

def test_categories():
    driver = data.categories(**{},verbose=True)
    #execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_tags():
    driver = data.tags(**{ 'category_id': '125', 'file_type': 'json', 'realtime_start': '', 'realtime_end':   '', 'tag_names' : '', 'exclude_tag_names':'', 'tag_group_id': '', 'search_text': '', 'limit':'', 'offset':'', 'order_by':'', 'sort_order':'' },verbose=True)
    #execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  


if __name__ == '__main__':
    #test_answer('')
    #test_IIP()
    #test_datasetlist()
    #test_getParameterList()
    #test_getParameterValues()
    #test_NIPA()
    #test_fixedAssets()

==> datapungi_fed-0.3.1.tar.gz: datapungi_fed-0.3.1/datapungi_fed/tests/test_driversCI.py <==
import datapungi_fed as dp
import time
import pandas as pd
import os


def executeCode(stringIn):
    '''
      auxiliary function for tests: get the requests code as a string and try to execute it.
    '''
    try:
        exec(stringIn+'\n')      #exec('print("hi")') #
        return(dict( codeRun = True, codeOutput = locals()['df_output']   ))   #try to output the dataframe called df_output
    except:
        try:
            exec(stringIn)  #if no dataframe called output, try to see it at least can exec the code
            return(dict(codeRun = True, codeOutput = pd.DataFrame([])))
        except:
            return(dict(codeRun = False, codeOutput = pd.DataFrame([])))

# start  the driver - used by all tests
def startDriver(cmdopt):
    global data
    if not cmdopt == "":
        connectionParameters = {"key": cmdopt, "url": "https://api.stlouisfed.org/"}
    else:
        connectionParameters = {}
    data = dp.data(connectionParameters)
    return(data)  

def test_categories(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories(125,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  


###########################################################################################################
###  Tests of the categories dbgroup

def test_categories(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories(125,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_categoriesLong(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories['category'](125,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_categoriesChildren(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories['children'](13,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_categoriesRelated(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories['related'](32073,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_categoriesSeries(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories['series'](125,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_categoriesTags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories['tags'](125,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_categoriesRelatedTags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.categories['related_tags'](125,tag_names="services;quarterly",verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

###########################################################################################################
###  Tests of the releases dbgroup

def test_releases(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases(verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_releasesLong(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['releases'](verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_releasesDates(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release/dates'](release_id=53,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_releasesRelease(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release'](release_id=53,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_releasesReleaseDates(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release/dates'](release_id=53,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_releasesReleaseSeries(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release/series'](release_id=53,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_releasesReleaseSources(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release/sources'](release_id=53,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_releasesReleaseTags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release/tags'](release_id=53,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_releasesReleaseRelatedTags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release/related_tags'](release_id='86',tag_names='sa;foreign',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_releasesReleaseTables(cmdopt):
    data = startDriver(cmdopt)
    driver = data.releases['release/tables'](release_id=53,verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

###########################################################################################################
## Test Series

#def test_series(cmdopt):
#    data = startDriver(cmdopt)
#    driver = data.series('gdp',verbose=True)
#    execCode = executeCode(driver['code']) 
#    assert driver['request'].status_code == 200  #test if connection was stablished
#    assert not driver['dataFrame'].empty         #cleaned up output is not empty
#    #assert execCode['codeRun']                   #try to execute the code.
#    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_seriesSeries(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['series']('GDP',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  

def test_seriesCategories(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['categories']('EXJPUS',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

#def test_seriesObservations(cmdopt): #seriesLong
#    data = startDriver(cmdopt)
#    driver = data.series['observations']('GNP',verbose=True)
#    execCode = executeCode(driver['code']) 
#    assert driver['request'].status_code == 200  #test if connection was stablished
#    assert not driver['dataFrame'].empty         #cleaned up output is not empty
#    #assert execCode['codeRun']                   #try to execute the code.
#    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesRelease(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['release']('IRA',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesSearch(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['search'](search_text='monetary+service+index',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesSearchTags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['search/tags'](series_search_text='monetary+service+index',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesSearchRelatedTags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['search/related_tags'](series_search_text='mortgage+rate',tag_names='30-year;frb',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesTags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['tags'](series_id='STLFSI',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesCategories(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['categories']('EXJPUS',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesUpdates(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['updates'](verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

def test_seriesVintagedates(cmdopt):
    data = startDriver(cmdopt)
    driver = data.series['vintagedates']('GNPCA',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the 

###########################################################################################################
## Test Tags

def test_tags(cmdopt):
    data = startDriver(cmdopt)
    driver = data.tags(tag_names='monetary+aggregates;weekly',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    #assert execCode['codeOutput'].equals(driver['dataFrame']) #test if the output of the code equals the output of the  
 
def test_tagsLong(cmdopt):   
    data = startDriver(cmdopt)
    driver = data.tags['tags'](tag_names='monetary+aggregates;weekly',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.

def test_tagsRelated(cmdopt): 
    data = startDriver(cmdopt)
    driver = data.tags['related_tags'](tag_names='monetary+aggregates;weekly',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.
    
def test_tagsSeries(cmdopt): 
    data = startDriver(cmdopt)    
    driver = data.tags['tags/series'](tag_names='slovenia;food;oecd',verbose=True)
    execCode = executeCode(driver['code']) 
    assert driver['request'].status_code == 200  #test if connection was stablished
    assert not driver['dataFrame'].empty         #cleaned up output is not empty
    #assert execCode['codeRun']                   #try to execute the code.


if __name__ == '__main__':
    test_startDriver()     
    test_categories()     
    test_tags()     
    #test_s()     
    #test_()
